#
# spec file for package python-marshmallow
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-marshmallow
Version:        3.5.1
Release:        bp155.2.9
Summary:        ORM/ODM/framework-agnostic library to convert datatypes from/to Python types
License:        MIT AND BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://marshmallow.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/m/marshmallow/marshmallow-%{version}.tar.gz
# https://github.com/humitos/sphinx-version-warning/issues/22
Patch0:         python-marshmallow-no-version-warning.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       %{name}-docs
Suggests:       python-python-dateutil
Suggests:       python-simplejson
BuildArch:      noarch
# SECTION doc build requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-alabaster
BuildRequires:  python3-sphinx-issues
BuildRequires:  python3-sphinx-version-warning
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module simplejson}
# /SECTION
%python_subpackages

%package -n %{name}-docs
Summary:        Documentation files for %{name}
Group:          Documentation/Other

%description
marshmallow is an ORM/ODM/framework-agnostic library for converting complex
datatypes, such as objects, to and from native Python datatypes.

%description -n %{name}-docs
HTML Documentation and examples for %{name}.

%prep
%setup -q -n marshmallow-%{version}
%autopatch -p1

%build
%python_build
sphinx-build docs/ docs/_build/html
rm -r docs/_build/html/.buildinfo docs/_build/html/.doctrees

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE NOTICE
%{python_sitelib}/*

%files -n %{name}-docs
%doc examples docs/_build/html/

%changelog
* Wed Apr  1 2020 pgajdos@suse.com
- version update to 3.5.1
  - Includes bug fix from 2.21.0.
  - Fix list of nullable nested fields ``List(Nested(Field, allow_none=True)``
    (:issue:`1497`). Because this fix reverts an optimization introduced to
    speed-up serialization and deserialization of lists of nested fields, a
    negative impact on performance in this specific case is expected.
  - Improve type coverage (:issue:`1479`). Thanks :user:`Reskov`.
  - Fix typing for ``data`` param of ``Schema.load`` and ``ValidationError`` (:issue:`1492`).
    Thanks :user:`mehdigmira` for reporting and thanks :user:`dfirst` for the PR.
  - Remove unnecessary typecasts (:pr:`1500`). Thanks :user:`hukkinj1`.
  - Remove useless ``_serialize`` override in ``UUID`` field (:pr:`1489`).
  - ``fields.Nested`` may take a callable that returns a schema instance.
    Use this to resolve order-of-declaration issues when schemas nest each other (:issue:`1146`).
  - Passing the string ``"self"`` to ``fields.Nested`` is deprecated.
    Use a callable instead.
  - Fix typing for ``Number._format_num`` (:pr:`1466`). Thanks :user:`hukkinj1`.
  - Make mypy stricter and remove dead code (:pr:`1467`). Thanks again, :user:`hukkinj1`.
* Wed Nov 13 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 3.2.2:
  - Bug fixes:
  - Don't load fields for which ``load_only`` and ``dump_only`` are both ``True`` (:pr:`1448`).
  - Fix types in ``marshmallow.validate`` (:pr:`1446`).
  - Support:
  - Test against Python 3.8 (pr:`1431`).
* Tue Oct  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.2.1
  * Fix typing for Schema.dump[s]
  * Fix compatibility with Python < 3.5.3
  * Fix bug that raised an uncaught error when a nested schema
    instance had an unpickleable object in its context
  * Fix propagating dot-delimited only and exclude parameters to
    nested schema instances
  * Few bug fixes
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.3:
  * Handle when data_key is an empty string
  * Includes bug fix from 2.20.3
  * Fix incorrect super() call in SchemaMeta.__init__
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.1
  * Many changes, some of them breaking. For example:
  * Remove support for Python 2 (#1120). Only Python>=3.5 is supported.
  * Allow input value to be included in error messages for a number of fields.
  * Change ordering of keys and values arguments to fields.Dict.
  * Please read upstream changelog.
- Drop upstreamed patches reproducible.patch and pytest5.patch
* Wed Jul 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix building with pytest5 from upstream git:
  * pytest5.patch
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.19.5:
  * Fix deserializing ISO8601-formatted datetimes with less than 6-digit miroseconds (:issue:`1251`). Thanks :user:`diego-plan9` for reporting.
  * Microseconds no longer gets lost when deserializing datetimes without dateutil installed (:issue:`1147`).
  * Fix bug where nested fields in Meta.exclude would not work on multiple instantiations (:issue:`1212`). Thanks :user:`MHannila` for reporting.
* Tue May 28 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make build reproducible (boo#1047218)
* Fri May 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.19.2
  * Handle OverflowError when (de)serializing large integers with
    fields.Float
* Fri Apr  5 2019 Petr Gajdos <pgajdos@suse.com>
- version update to 2.19.1
  - Fix bug where ``Nested(many=True)`` would skip first element when
    serializing a generator (:issue:`1163`). Thanks :user:`khvn26` for the
    catch and patch.
  - A `RemovedInMarshmallow3` warning is raised when using
    `fields.FormattedString`. Use `fields.Method` or `fields.Function`
    instead (:issue:`1141`).
  - A ``ChangedInMarshmallow3Warning`` is no longer raised when
    ``strict=False`` (:issue:`1108`). Thanks :user:`Aegdesil` for
    reporting.
  - Add warnings for functions in ``marshmallow.utils`` that are removed in
    marshmallow 3.
  - Copying ``missing`` with ``copy.copy`` or ``copy.deepcopy`` will not
    duplicate it (:pr:`1099`).
  - Add ``marshmallow.__version_info__`` (:pr:`1074`).
  - Add warnings for API that is deprecated or changed to help users
    prepare for marshmallow 3 (:pr:`1075`).
  - Prevent memory leak when dynamically creating classes with ``type()``
    (:issue:`732`). Thanks :user:`asmodehn` for writing the tests to
    reproduce this issue.
  - Prevent warning about importing from ``collections`` on Python 3.7
    (:issue:`1027`). Thanks :user:`nkonin` for reporting and
    :user:`jmargeta` for the PR.
  - Remove spurious warning about implicit collection handling
    (:issue:`998`). Thanks :user:`lalvarezguillen` for reporting.
  - Allow username without password in basic auth part of the url in
    ``fields.Url`` (:pr:`982`). Thanks user:`alefnula` for the PR.
  - Prevent ``TypeError`` when a non-collection is passed to a ``Schema`` with ``many=True``.
    Instead, raise ``ValidationError`` with ``{'_schema': ['Invalid input type.']}`` (:issue:`906`).
  - Fix ``root`` attribute for nested container fields on list
    on inheriting schemas (:issue:`956`). Thanks :user:`bmcbu`
    for reporting.
  - Handle empty SQLAlchemy lazy lists gracefully when dumping (:issue:`948`).
    Thanks :user:`vke-code` for the catch and :user:`YuriHeupa` for the patch.
  - Respect ``load_from`` when reporting errors for ``@validates('field_name')``
    (:issue:`748`). Thanks :user:`m-novikov` for the catch and patch.
  - Fix passing ``only`` as a string to ``nested`` when the passed field
    defines ``dump_to`` (:issue:`800`, :issue:`822`). Thanks
    :user:`deckar01` for the catch and patch.
  - Fix a race condition in validation when concurrent threads use the
    same ``Schema`` instance (:issue:`783`). Thanks :user:`yupeng0921` and
    :user:`lafrech` for the fix.
  - Fix serialization behavior of
    ``fields.List(fields.Integer(as_string=True))`` (:issue:`788`). Thanks
    :user:`cactus` for reporting and :user:`lafrech` for the fix.
  - Fix behavior of ``exclude`` parameter when passed from parent to
    nested schemas (:issue:`728`). Thanks :user:`timc13` for reporting and
    :user:`deckar01` for the fix.
  - :cve:`CVE-2018-17175`: Fix behavior when an empty list is passed as the ``only`` argument
    (:issue:`772`). Thanks :user:`deckar01` for reporting and thanks
    :user:`lafrech` for the fix.
  - Handle ``UnicodeDecodeError`` when deserializing ``bytes`` with a
    ``String`` field (:issue:`650`). Thanks :user:`dan-blanchard` for the
    suggestion and thanks :user:`4lissonsilveira` for the PR.
  - Add ``require_tld`` parameter to ``validate.URL`` (:issue:`664`).
    Thanks :user:`sduthil` for the suggestion and the PR.
- added patches
  + python-marshmallow-no-version-warning.patch
- deleted patches
  + patch-remove-unsupported-theme-option.patch (upstreamed)
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Aug 19 2017 sebix+novell.com@sebix.at
- initial package
